@@ -6,6 +6,7 @@ import (
 	"path/filepath"
 	"strings"
 
+	"github.com/lima-vm/lima/pkg/cidata"
 	"github.com/lima-vm/lima/pkg/instance"
 	"github.com/lima-vm/lima/pkg/store"
 	"github.com/lima-vm/lima/pkg/store/filenames"
@@ -39,6 +40,9 @@ func factoryResetAction(_ *cobra.Command, args []string) error {
 		}
 		return err
 	}
+	if inst.Protected {
+		return errors.New("instance is protected to prohibit accidental factory-reset (Hint: use `limactl unprotect`)")
+	}
 
 	instance.StopForcibly(inst)
 
@@ -46,15 +50,25 @@ func factoryResetAction(_ *cobra.Command, args []string) error {
 	if err != nil {
 		return err
 	}
+	retain := map[string]struct{}{
+		filenames.LimaVersion:  {},
+		filenames.Protected:    {},
+		filenames.VzIdentifier: {},
+	}
 	for _, f := range fi {
 		path := filepath.Join(inst.Dir, f.Name())
-		if !strings.HasSuffix(path, ".yaml") && !strings.HasSuffix(path, ".yml") && f.Name() != filenames.VzIdentifier {
+		if _, ok := retain[f.Name()]; !ok && !strings.HasSuffix(path, ".yaml") && !strings.HasSuffix(path, ".yml") {
 			logrus.Infof("Removing %q", path)
 			if err := os.Remove(path); err != nil {
 				logrus.Error(err)
 			}
 		}
 	}
+	// Regenerate the cloud-config.yaml, to reflect any changes to the global _config
+	if err := cidata.GenerateCloudConfig(inst.Dir, instName, inst.Config); err != nil {
+		logrus.Error(err)
+	}
+
 	logrus.Infof("Instance %q has been factory reset", instName)
 	return nil
 }
