@@ -24,3 +24,8 @@ if [[ ${BASH_VERSINFO:-0} -lt 4 ]]; then
 fi
 
 : "${LIMA_HOME:=$HOME/.lima}"
+_IPERF3=iperf3
+# iperf3-darwin does some magic on macOS to avoid "No route on host" on macOS 15
+# https://github.com/lima-vm/socket_vmnet/issues/85
+[ "$(uname -s)" = "Darwin" ] && _IPERF3="iperf3-darwin"
+: "${IPERF3:=$_IPERF3}"
