@@ -4,6 +4,8 @@ import (
 	"os"
 	"path/filepath"
 	"testing"
+
+	"gotest.tools/v3/assert"
 )
 
 func FuzzConvertToRaw(f *testing.F) {
@@ -11,9 +13,7 @@ func FuzzConvertToRaw(f *testing.F) {
 		srcPath := filepath.Join(t.TempDir(), "src.img")
 		destPath := filepath.Join(t.TempDir(), "dest.img")
 		err := os.WriteFile(srcPath, imgData, 0o600)
-		if err != nil {
-			t.Fatal(err)
-		}
+		assert.NilError(t, err)
 		_ = ConvertToRaw(srcPath, destPath, &size, withBacking)
 	})
 }
