@@ -14,14 +14,12 @@ func DNSAddresses() ([]string, error) {
 		return nil, err
 	}
 	var addresses []string
-	if len(nwData) > 0 {
-		// Return DNS addresses from the first interface that has an IPv4 address.
-		// The networks are in service order already.
-		for _, nw := range nwData {
-			if len(nw.IPv4.Addresses) > 0 {
-				addresses = nw.DNS.ServerAddresses
-				break
-			}
+	// Return DNS addresses from the first interface that has an IPv4 address.
+	// The networks are in service order already.
+	for _, nw := range nwData {
+		if len(nw.IPv4.Addresses) > 0 {
+			addresses = nw.DNS.ServerAddresses
+			break
 		}
 	}
 	return addresses, nil
