@@ -1,6 +1,7 @@
 package osutil
 
 import (
+	"errors"
 	"fmt"
 	"io/fs"
 	"os"
@@ -48,3 +49,7 @@ func SignalName(sig os.Signal) string {
 		return fmt.Sprintf("Signal(%d)", sig)
 	}
 }
+
+func Sysctl(name string) (string, error) {
+	return "", errors.New("sysctl: unimplemented on Windows")
+}
