@@ -496,6 +496,9 @@ func Cmdline(ctx context.Context, cfg Config) (exe string, args []string, err er
 		if version.LessThan(*semver.New(MinimumQemuVersion)) {
 			logrus.Fatalf("QEMU %v is too old, %v or later required", version, MinimumQemuVersion)
 		}
+		if y.VMOpts.QEMU.MinimumVersion != nil && version.LessThan(*semver.New(*y.VMOpts.QEMU.MinimumVersion)) {
+			logrus.Fatalf("QEMU %v is too old, template requires %q or later", version, *y.VMOpts.QEMU.MinimumVersion)
+		}
 		if runtime.GOOS == "darwin" && runtime.GOARCH == "arm64" && version.Equal(*semver.New("8.2.0")) {
 			logrus.Fatal("QEMU 8.2.0 is no longer supported on ARM Mac due to <https://gitlab.com/qemu-project/qemu/-/issues/1990>. " +
 				"Please upgrade QEMU to v8.2.1 (or downgrade to v8.1.x).")
@@ -570,7 +573,12 @@ func Cmdline(ctx context.Context, cfg Config) (exe string, args []string, err er
 		}
 		args = appendArgsIfNoConflict(args, "-machine", machine)
 	case limayaml.RISCV64:
-		machine := "virt,accel=" + accel
+		// https://github.com/tianocore/edk2/blob/edk2-stable202408/OvmfPkg/RiscVVirt/README.md#test
+		// > Note: the `acpi=off` machine property is specified because Linux guest
+		// > support for ACPI (that is, the ACPI consumer side) is a work in progress.
+		// > Currently, `acpi=off` is recommended unless you are developing ACPI support
+		// > yourself.
+		machine := "virt,acpi=off,accel=" + accel
 		args = appendArgsIfNoConflict(args, "-machine", machine)
 	case limayaml.ARMV7L:
 		machine := "virt,accel=" + accel
@@ -610,7 +618,7 @@ func Cmdline(ctx context.Context, cfg Config) (exe string, args []string, err er
 			firmware = downloadedFirmware
 			logrus.Infof("Using existing firmware (%q)", firmware)
 		}
-		if firmware == "" && *y.Arch != limayaml.RISCV64 {
+		if firmware == "" {
 			firmware, err = getFirmware(exe, *y.Arch)
 			if err != nil {
 				return "", nil, err
@@ -626,35 +634,33 @@ func Cmdline(ctx context.Context, cfg Config) (exe string, args []string, err er
 	baseDisk := filepath.Join(cfg.InstanceDir, filenames.BaseDisk)
 	diffDisk := filepath.Join(cfg.InstanceDir, filenames.DiffDisk)
 	extraDisks := []string{}
-	if len(y.AdditionalDisks) > 0 {
-		for _, d := range y.AdditionalDisks {
-			diskName := d.Name
-			disk, err := store.InspectDisk(diskName)
-			if err != nil {
-				logrus.Errorf("could not load disk %q: %q", diskName, err)
-				return "", nil, err
-			}
-
-			if disk.Instance != "" {
-				if disk.InstanceDir != cfg.InstanceDir {
-					logrus.Errorf("could not attach disk %q, in use by instance %q", diskName, disk.Instance)
-					return "", nil, err
-				}
-				err = disk.Unlock()
-				if err != nil {
-					logrus.Errorf("could not unlock disk %q to reuse in the same instance %q", diskName, cfg.Name)
-					return "", nil, err
-				}
-			}
-			logrus.Infof("Mounting disk %q on %q", diskName, disk.MountPoint)
-			err = disk.Lock(cfg.InstanceDir)
-			if err != nil {
-				logrus.Errorf("could not lock disk %q: %q", diskName, err)
-				return "", nil, err
-			}
-			dataDisk := filepath.Join(disk.Dir, filenames.DataDisk)
-			extraDisks = append(extraDisks, dataDisk)
+	for _, d := range y.AdditionalDisks {
+		diskName := d.Name
+		disk, err := store.InspectDisk(diskName)
+		if err != nil {
+			logrus.Errorf("could not load disk %q: %q", diskName, err)
+			return "", nil, err
 		}
+
+		if disk.Instance != "" {
+			if disk.InstanceDir != cfg.InstanceDir {
+				logrus.Errorf("could not attach disk %q, in use by instance %q", diskName, disk.Instance)
+				return "", nil, err
+			}
+			err = disk.Unlock()
+			if err != nil {
+				logrus.Errorf("could not unlock disk %q to reuse in the same instance %q", diskName, cfg.Name)
+				return "", nil, err
+			}
+		}
+		logrus.Infof("Mounting disk %q on %q", diskName, disk.MountPoint)
+		err = disk.Lock(cfg.InstanceDir)
+		if err != nil {
+			logrus.Errorf("could not lock disk %q: %q", diskName, err)
+			return "", nil, err
+		}
+		dataDisk := filepath.Join(disk.Dir, filenames.DataDisk)
+		extraDisks = append(extraDisks, dataDisk)
 	}
 
 	isBaseDiskCDROM, err := iso9660util.IsISO9660(baseDisk)
@@ -723,7 +729,7 @@ func Cmdline(ctx context.Context, cfg Config) (exe string, args []string, err er
 
 	for i, nw := range y.Networks {
 		if nw.Lima != "" {
-			nwCfg, err := networks.Config()
+			nwCfg, err := networks.LoadConfig()
 			if err != nil {
 				return "", nil, err
 			}
@@ -953,48 +959,48 @@ func FindVirtiofsd(qemuExe string) (string, error) {
 		candidates = append(candidates, filepath.Join("/usr", relativePath))
 	}
 
-	for _, vhostConfigsDir := range candidates {
-		logrus.Debugf("Checking vhost directory %s", vhostConfigsDir)
+	for _, vhostCfgsDir := range candidates {
+		logrus.Debugf("Checking vhost directory %s", vhostCfgsDir)
 
-		configEntries, err := os.ReadDir(vhostConfigsDir)
+		cfgEntries, err := os.ReadDir(vhostCfgsDir)
 		if err != nil {
 			logrus.Debugf("Failed to list vhost directory: %v", err)
 			continue
 		}
 
-		for _, configEntry := range configEntries {
-			logrus.Debugf("Checking vhost config %s", configEntry.Name())
-			if !strings.HasSuffix(configEntry.Name(), ".json") {
+		for _, cfgEntry := range cfgEntries {
+			logrus.Debugf("Checking vhost vhostCfg %s", cfgEntry.Name())
+			if !strings.HasSuffix(cfgEntry.Name(), ".json") {
 				continue
 			}
 
-			var config vhostUserBackend
-			contents, err := os.ReadFile(filepath.Join(vhostConfigsDir, configEntry.Name()))
+			var vhostCfg vhostUserBackend
+			contents, err := os.ReadFile(filepath.Join(vhostCfgsDir, cfgEntry.Name()))
 			if err == nil {
-				err = json.Unmarshal(contents, &config)
+				err = json.Unmarshal(contents, &vhostCfg)
 			}
 
 			if err != nil {
-				logrus.Warnf("Failed to load vhost-user config %s: %v", configEntry.Name(), err)
+				logrus.Warnf("Failed to load vhost-user config %s: %v", cfgEntry.Name(), err)
 				continue
 			}
-			logrus.Debugf("%v", config)
+			logrus.Debugf("%v", vhostCfg)
 
-			if config.BackendType != "fs" {
+			if vhostCfg.BackendType != "fs" {
 				continue
 			}
 
 			// Only rust virtiofsd supports --version, so use that to make sure this isn't
 			// QEMU's virtiofsd, which requires running as root.
-			cmd := exec.Command(config.Binary, "--version")
+			cmd := exec.Command(vhostCfg.Binary, "--version")
 			output, err := cmd.CombinedOutput()
 			if err != nil {
 				logrus.Warnf("Failed to run %s --version (is this QEMU virtiofsd?): %s: %s",
-					config.Binary, err, output)
+					vhostCfg.Binary, err, output)
 				continue
 			}
 
-			return config.Binary, nil
+			return vhostCfg.Binary, nil
 		}
 	}
 
@@ -1028,6 +1034,14 @@ func qemuArch(arch limayaml.Arch) string {
 	return arch
 }
 
+// qemuEdk2 returns the arch string used by `/usr/local/share/qemu/edk2-*-code.fd`.
+func qemuEdk2Arch(arch limayaml.Arch) string {
+	if arch == limayaml.RISCV64 {
+		return "riscv"
+	}
+	return qemuArch(arch)
+}
+
 func Exe(arch limayaml.Arch) (exe string, args []string, err error) {
 	exeBase := "qemu-system-" + qemuArch(arch)
 	envK := "QEMU_SYSTEM_" + strings.ToUpper(qemuArch(arch))
@@ -1091,7 +1105,7 @@ func getQemuVersion(qemuExe string) (*semver.Version, error) {
 
 func getFirmware(qemuExe string, arch limayaml.Arch) (string, error) {
 	switch arch {
-	case limayaml.X8664, limayaml.AARCH64, limayaml.ARMV7L:
+	case limayaml.X8664, limayaml.AARCH64, limayaml.ARMV7L, limayaml.RISCV64:
 	default:
 		return "", fmt.Errorf("unexpected architecture: %q", arch)
 	}
@@ -1105,7 +1119,7 @@ func getFirmware(qemuExe string, arch limayaml.Arch) (string, error) {
 	localDir := filepath.Dir(binDir)                             // "/usr/local"
 	userLocalDir := filepath.Join(currentUser.HomeDir, ".local") // "$HOME/.local"
 
-	relativePath := fmt.Sprintf("share/qemu/edk2-%s-code.fd", qemuArch(arch))
+	relativePath := fmt.Sprintf("share/qemu/edk2-%s-code.fd", qemuEdk2Arch(arch))
 	candidates := []string{
 		filepath.Join(userLocalDir, relativePath), // XDG-like
 		filepath.Join(localDir, relativePath),     // macOS (homebrew)
@@ -1119,7 +1133,7 @@ func getFirmware(qemuExe string, arch limayaml.Arch) (string, error) {
 		// Fedora package "edk2-ovmf"
 		candidates = append(candidates, "/usr/share/edk2/ovmf/OVMF_CODE.fd")
 		// openSUSE package "qemu-ovmf-x86_64"
-		candidates = append(candidates, "/usr/share/qemu/ovmf-x86_64-code.bin")
+		candidates = append(candidates, "/usr/share/qemu/ovmf-x86_64.bin")
 		// Archlinux package "edk2-ovmf"
 		candidates = append(candidates, "/usr/share/edk2-ovmf/x64/OVMF_CODE.fd")
 	case limayaml.AARCH64:
@@ -1132,6 +1146,8 @@ func getFirmware(qemuExe string, arch limayaml.Arch) (string, error) {
 		// Debian package "qemu-efi-arm"
 		// Fedora package "edk2-arm"
 		candidates = append(candidates, "/usr/share/AAVMF/AAVMF32_CODE.fd")
+	case limayaml.RISCV64:
+		// NOP, as EDK2 for RISCV64 is not packaged yet in well-known distros.
 	}
 
 	logrus.Debugf("firmware candidates = %v", candidates)
