@@ -18,7 +18,11 @@ import (
 )
 
 func PassFDToUnix(unixSock string) (*os.File, error) {
-	unixConn, err := net.Dial("unix", unixSock)
+	unixAddr, err := net.ResolveUnixAddr("unix", unixSock)
+	if err != nil {
+		return nil, err
+	}
+	unixConn, err := net.DialUnix("unix", nil, unixAddr)
 	if err != nil {
 		return nil, err
 	}
@@ -27,7 +31,7 @@ func PassFDToUnix(unixSock string) (*os.File, error) {
 	if err != nil {
 		return nil, err
 	}
-	err = fd.Put(unixConn.(*net.UnixConn), server)
+	err = fd.Put(unixConn, server)
 	if err != nil {
 		return nil, err
 	}
@@ -96,14 +100,7 @@ func (c *qemuPacketConn) Read(b []byte) (n int, err error) {
 		// Likely connection closed by peer.
 		return 0, err
 	}
-
-	reader := io.LimitReader(c.Conn, int64(size))
-	_, err = reader.Read(b)
-	if err != nil {
-		// Likely connection closed by peer.
-		return 0, err
-	}
-	return int(size), nil
+	return io.ReadFull(c.Conn, b[:size])
 }
 
 // Write writes a QEMU packet containing the raw packet. Returns (len(b), nil)
@@ -116,13 +113,12 @@ func (c *qemuPacketConn) Write(b []byte) (int, error) {
 		return 0, err
 	}
 
-	start := 0
-	for start < size {
-		nw, err := c.Conn.Write(b[start:])
+	for len(b) != 0 {
+		n, err := c.Conn.Write(b)
 		if err != nil {
 			return 0, err
 		}
-		start += nw
+		b = b[n:]
 	}
 	return size, nil
 }
